@@ -26,6 +26,7 @@ from .asgi_types import (
     Receive,
     ReceiveMessage,
     Scope,
+    ScopeSession,
     Send,
     WebSocketAcceptEvent,
     WebSocketCloseEvent,
@@ -140,6 +141,7 @@ __all__ = (
     "RouteHandlerType",
     "Scope",
     "Scope",
+    "ScopeSession",
     "Send",
     "Send",
     "Serializer",
